asr.fere
========

.. automodule:: asr.fere

   
   
   .. rubric:: Functions

   
   .. autofunction:: count
   .. autofunction:: create_corrected_db
   .. autofunction:: elements_from_refs
   .. autofunction:: formulas_eq
   .. autofunction:: get_dE_alpha
   .. autofunction:: get_hof
   .. autofunction:: load_data
   .. autofunction:: minimize_error
   .. autofunction:: multiply_formula
   .. autofunction:: only
   .. autofunction:: parse_reactions
   .. autofunction:: parse_refs
   .. autofunction:: safe_get
   .. autofunction:: select
   .. autofunction:: single
   .. autofunction:: unique
   .. autofunction:: where
   
   

   
   
   

   
   
   .. rubric:: Exceptions

   
   .. autoexception:: DBAlreadyExistsError
   .. autoexception:: MaterialNotFoundError
   .. autoexception:: ParseError
   
   